==> v4.2.4.tar.gz: 2fauth/resources/lang/bg/commons.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'cancel' => 'Отказ',
    'update' => 'Актуализация',
    'copy' => 'Копиране',
    'copy_to_clipboard' => 'Копиране в клипборда',
    'copied_to_clipboard' => 'Копирано в клипборда',
    'profile' => 'Профил',
    'edit' => 'Редактиране',
    'delete' => 'Изтрий',
    'disable' => 'Деактивиране',
    'enable' => 'Активирай',
    'create' => 'Създай',
    'save' => 'Запази',
    'close' => 'Затвори',
    'clear' => 'Изчисти',
    'clear_search' => 'Изчисти търсенето',
    'demo_do_not_post_sensitive_data' => 'Това е демонстрационна програма. Не записвайте чуествителна информация',
    'testing_do_not_post_sensitive_data' => 'Това е тестова програма. Не записвайте чуествителна информация',
    'selected' => 'избрани',
    'name' => 'Име',
    'manage' => 'Управление',
    'done' => 'Готово',
    'new' => 'Нов',
    'back' => 'Назад',
    'move' => 'Премести',
    'export' => 'Експорт',
    'all' => 'Всички',
    'select_all' => 'Избери всички',
    'clear_selection' => 'Изчисти избраните',
    'sort_descending' => 'Сортирай низходящо',
    'sort_ascending' => 'Cортирай възходящо',
    'rename' => 'Преименуване',
    'new_name' => 'Ново име',
    'options' => 'Настроики',
    'reload' => 'презаредите',
    'some_data_have_changed' => 'Някой записи са променени. Трябва да',
    'generate' => 'Създаване',
    'generating_otp' => 'Generating OTP',
    'open_in_browser' => 'Отвори в браузър',
    'continue' => 'Продължи',
    'discard' => 'Откажи',
    'about' => 'Относно',
    'usefull_links' => 'Полезни връзки',
    'environment' => 'Среда',
    'credits' => 'Заслуги',
    '2fauth_teaser' => 'Уеб приложение за управление на вашите акаунти с двуфакторно удостоверяване (2FA) и генериране на техните кодове за сигурност',
    'made_with' => 'Изработено с',
    'ui_icons_by' => 'Икони',
    'logos_by' => 'Лога от',
    'search' => 'Търсене',
    'resources' => 'Ресурси',
    'check_for_update' => 'Проверка за нова версия',
    'check_for_update_help' => 'Автоматично проверявайте (веднъж седмично) и предупреди, когато в Github се публикува нова версия на 2FAuth',
    'you_are_up_to_date' => 'Тази инстанция е актуална',
    '2fauth_description' => 'Уеб приложение за управление на вашите акаунти с двуфакторно удостоверяване (2FA) и генериране на техните кодове за сигурност',
    'image_of_qrcode_to_scan' => 'Изображение на QR код за сканиране',
    'file' => 'Файл',
    'or' => 'ИЛИ',
    'close_the_x_page' => 'Затвори {pagetitle} страницата',
];

==> v5.0.1.tar.gz: 2fauth/resources/lang/bg/commons.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Authentication Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used during authentication for various
    | messages that we need to display to the user. You are free to modify
    | these language lines according to your application's requirements.
    |
    */

    'cancel' => 'Отказ',
    'update' => 'Актуализация',
    'copy' => 'Копиране',
    'copy_to_clipboard' => 'Копиране в клипборда',
    'copied_to_clipboard' => 'Копирано в клипборда',
    'profile' => 'Профил',
    'edit' => 'Редактиране',
    'delete' => 'Изтрий',
    'disable' => 'Деактивиране',
    'enable' => 'Активирай',
    'create' => 'Създай',
    'save' => 'Запази',
    'close' => 'Затвори',
    'clear' => 'Изчисти',
    'clear_search' => 'Изчисти търсенето',
    'demo_do_not_post_sensitive_data' => 'Това е демонстрационна програма. Не записвайте чувствителна информация',
    'testing_do_not_post_sensitive_data' => 'Това е тестова програма. Не записвайте чувствителна информация',
    'selected' => 'избрани',
    'name' => 'Име',
    'manage' => 'Управление',
    'done' => 'Готово',
    'new' => 'Нов',
    'back' => 'Назад',
    'move' => 'Премести',
    'export' => 'Експорт',
    'all' => 'Всички',
    'select_all' => 'Избери всички',
    'clear_selection' => 'Изчисти избраните',
    'sort_descending' => 'Сортирай низходящо',
    'sort_ascending' => 'Cортирай възходящо',
    'rename' => 'Преименуване',
    'new_name' => 'Ново име',
    'options' => 'Настройки',
    'reload' => 'презаредите',
    'refresh' => 'Refresh',
    'data_refreshed_to_reflect_server_changes' => 'Data has been refresh to reflect server-side changes',
    'generate' => 'Създаване',
    'generating_otp' => 'Генериране на OTP',
    'open_in_browser' => 'Отвори в браузър',
    'continue' => 'Продължи',
    'discard' => 'Откажи',
    'about' => 'Относно',
    'usefull_links' => 'Полезни връзки',
    'environment' => 'Среда',
    'credits' => 'Заслуги',
    '2fauth_teaser' => 'Уеб приложение за управление на вашите акаунти с двуфакторно удостоверяване (2FA) и генериране на техните кодове за сигурност',
    'made_with' => 'Изработено с',
    'ui_icons_by' => 'Икони',
    'logos_by' => 'Лога от',
    'search' => 'Търсене',
    'resources' => 'Ресурси',
    'check_for_update' => 'Проверка за нова версия',
    'check_for_update_help' => 'Автоматично проверявайте (веднъж седмично) и предупреди, когато в Github се публикува нова версия на 2FAuth',
    'you_are_up_to_date' => 'Тази инстанция е актуална',
    '2fauth_description' => 'Уеб приложение за управление на вашите акаунти с двуфакторно удостоверяване (2FA) и генериране на техните кодове за сигурност',
    'image_of_qrcode_to_scan' => 'Изображение на QR код за сканиране',
    'file' => 'Файл',
    'or' => 'ИЛИ',
    'close_the_x_page' => 'Затвори {pagetitle} страницата',
    'submit' => 'Submit',
    'default' => 'Default',
    'back_to_home' => 'Back to home',
    'nothing' => 'nothing',
];
